@@ -18,28 +18,82 @@ import json
 import os
 import re
 from collections import namedtuple
-from warnings import warn
 from os.path import join
+from warnings import warn
 
+from quantulum3 import parser as quantity_parser
 
 from lingua_nostra.bracket_expansion import SentenceTreeParser
 from lingua_nostra.internal import localized_function, \
     populate_localized_function_dict, get_active_langs, \
-    get_full_lang_code, get_default_lang, get_default_loc, \
-    is_supported_full_lang, _raise_unsupported_language, \
-    UnsupportedLanguageError, NoneLangWarning, InvalidLangWarning, \
-    FunctionNotLocalizedError
-
+    get_full_lang_code, get_default_loc, \
+    is_supported_full_lang, UnsupportedLanguageError, NoneLangWarning, \
+    InvalidLangWarning, \
+    FunctionNotLocalizedError, get_primary_lang_code
+from lingua_nostra.time import now_local
 
 _REGISTERED_FUNCTIONS = ("nice_number",
                          "nice_time",
                          "pronounce_number",
+                         "pronounce_digits",
                          "nice_response",
                          "nice_duration")
 
 populate_localized_function_dict("format", langs=get_active_langs())
 
 
+@localized_function(run_own_code_on=[FunctionNotLocalizedError])
+def nice_units(utterance=None, lang=''):
+    """  Format a unit to a pronouncable string
+    Args:
+        unit (string): The unit abbreviation that is to be pronounced
+            (i.e. "C", "MW", "mW", "°F" etc)
+        utterance (string): A text in which the correct meaning of this
+            abbreviation becomes clear (i.e. "It's almost 30 C outside")
+            If given, the whole context will be parsed and the first unit
+            to be found returned
+        lang (string): the language to use, use Mycroft default language if
+            not provided
+    Returns:
+        (str): A fully de-abbreviated unit for insertion in a context like
+                situation (i.e. "degree Celsius", "percent")
+        (object): The parsed value of the quantity, if any (else None)
+    """
+    lang = get_primary_lang_code(lang)
+    pronounced_units = []
+
+    try:
+        quants = quantity_parser.parse(utterance, lang)
+        if not quants:
+            # Quantulum expects a unit to be prefixed with a quantifier
+            quants = quantity_parser.parse(f"1 {utterance}", lang)
+        for q in quants:
+            pronounced_units.append(str(q))
+    except NotImplementedError:
+        raise FunctionNotLocalizedError
+
+    return pronounced_units
+
+
+@localized_function(run_own_code_on=[FunctionNotLocalizedError])
+def expand_units(text, lang=""):
+    """
+        Format all units in a text and their amount into pronouncable strings
+        Args:
+            text (string): A text, ideally containing compact units
+                            (i.e. "It's almost 30 C outside")
+            lang (string): the language to use, use Mycroft default language if
+                not provided
+        Returns:
+            (str): A text with fully de-abbreviated units
+    """
+    lang = get_primary_lang_code(lang)
+    try:
+        return quantity_parser.inline_parse_and_expand(text, lang)
+    except NotImplementedError:
+        return text
+
+
 def _translate_word(name, lang=''):
     """ Helper to get word translations
 
@@ -119,12 +173,12 @@ class DateTimeFormat:
             str(int(number % 100 / 10))) or str(int(number % 100 / 10))
         x0 = (self.lang_config[lang]['number'].get(
             str(int(number % 100 / 10) * 10)) or
-            str(int(number % 100 / 10) * 10))
+              str(int(number % 100 / 10) * 10))
         xxx = (self.lang_config[lang]['number'].get(str(number % 1000)) or
                str(number % 1000))
         x00 = (self.lang_config[lang]['number'].get(str(int(
             number % 1000 / 100) * 100)) or
-            str(int(number % 1000 / 100) * 100))
+               str(int(number % 1000 / 100) * 100))
         x_in_x00 = self.lang_config[lang]['number'].get(str(int(
             number % 1000 / 100))) or str(int(number % 1000 / 100))
         xx00 = self.lang_config[lang]['number'].get(str(int(
@@ -134,11 +188,12 @@ class DateTimeFormat:
             number % 10000 / 100))) or str(int(number % 10000 / 100))
         x000 = (self.lang_config[lang]['number'].get(str(int(
             number % 10000 / 1000) * 1000)) or
-            str(int(number % 10000 / 1000) * 1000))
+                str(int(number % 10000 / 1000) * 1000))
         x_in_x000 = self.lang_config[lang]['number'].get(str(int(
             number % 10000 / 1000))) or str(int(number % 10000 / 1000))
         x0_in_x000 = self.lang_config[lang]['number'].get(str(int(
-            number % 10000 / 1000) * 10)) or str(int(number % 10000 / 1000) * 10)
+            number % 10000 / 1000) * 10)) or str(
+            int(number % 10000 / 1000) * 10)
         x_in_0x00 = self.lang_config[lang]['number'].get(str(int(
             number % 1000 / 100)) or str(int(number % 1000 / 100)))
 
@@ -305,6 +360,23 @@ def pronounce_number(number, lang='', places=2, short_scale=True,
     """
 
 
+@localized_function()
+def pronounce_digits(number, lang=None, places=2, all_digits=False):
+    """
+    Pronounce a number's digits, either colloquially or in full
+    In English, the colloquial way is usually to read two digits at a time,
+    treating each pair as a single number.
+    Examples:
+        >>> pronounce_number(127, all_digits=False)
+        'one twenty seven'
+        >>> pronounce_number(127, all_digits=True)
+        'one two seven'
+    Args:
+        number (int|float)
+        all_digits (bool): read every digit, rather than two digits at a time
+    """
+
+
 def nice_date(dt, lang='', now=None):
     """
     Format a datetime to a pronounceable date
@@ -358,6 +430,35 @@ def nice_date_time(dt, lang='', now=None, use_24hour=False,
                                              use_ampm)
 
 
+def nice_day(dt, date_format='MDY', include_month=True, lang=""):
+    if include_month:
+        month = nice_month(dt, date_format, lang)
+        if date_format == 'MDY':
+            return "{} {}".format(month, dt.strftime("%d"))
+        else:
+            return "{} {}".format(dt.strftime("%d"), month)
+    return dt.strftime("%d")
+
+
+def nice_weekday(dt, lang=""):
+    if lang in date_time_format.lang_config.keys():
+        localized_day_names = list(
+            date_time_format.lang_config[lang]['weekday'].values())
+        weekday = localized_day_names[dt.weekday()]
+    else:
+        weekday = dt.strftime("%A")
+    return weekday.capitalize()
+
+
+def nice_month(dt, date_format='MDY', lang=""):
+    if lang in date_time_format.lang_config.keys():
+        localized_month_names = date_time_format.lang_config[lang]['month']
+        month = localized_month_names[str(int(dt.strftime("%m")))]
+    else:
+        month = dt.strftime("%B")
+    return month.capitalize()
+
+
 def nice_year(dt, lang='', bc=False):
     """
         Format a datetime to a pronounceable year
@@ -380,6 +481,35 @@ def nice_year(dt, lang='', bc=False):
     return date_time_format.year_format(dt, full_code, bc)
 
 
+def get_date_strings(dt=None, date_format='MDY', time_format="full", lang=""):
+    lang = get_primary_lang_code(lang)
+    dt = dt or now_local()
+    timestr = nice_time(dt, lang, speech=False,
+                         use_24hour=time_format == "full")
+    monthstr = nice_month(dt, date_format, lang)
+    weekdaystr = nice_weekday(dt, lang)
+    yearstr = dt.strftime("%Y")
+    daystr = nice_day(dt, date_format, include_month=False, lang=lang)
+    if date_format == 'MDY':
+        return {
+            "date_string": dt.strftime("%-m/%-d/%Y"),
+            "time_string": timestr,
+            "month_string": monthstr,
+            "day_string": daystr,
+            'year_string': yearstr,
+            "weekday_string": weekdaystr
+        }
+    else:
+        return {
+            "date_string": dt.strftime("%Y/%-d/%-m"),
+            "time_string": timestr,
+            "month_string": monthstr,
+            "day_string": daystr,
+            'year_string': yearstr,
+            "weekday_string": weekdaystr
+        }
+
+
 @localized_function(run_own_code_on=[FunctionNotLocalizedError])
 def nice_duration(duration, lang='', speech=True):
     """ Convert duration in seconds to a nice spoken timespan
@@ -566,3 +696,53 @@ def nice_response(text, lang=''):
         assertEqual(nice_response_de("10 ^ 2"),
                          "10 hoch 2")
     """
+
+
+@localized_function(run_own_code_on=[FunctionNotLocalizedError])
+def nice_bytes(number, lang='', speech=True, binary=True, gnu=False):
+    """
+    turns a number of bytes into a string using appropriate units
+    prefixes - https://en.wikipedia.org/wiki/Binary_prefix
+    spoken binary units - https://en.wikipedia.org/wiki/Kibibyte
+    implementation - http://stackoverflow.com/a/1094933/2444609
+    :param number: number of bytes (int)
+    :param lang: lang_code, ignored for now (str)
+    :param speech: spoken form (True) or short units (False)
+    :param binary: 1 kilobyte = 1024 bytes (True) or 1 kilobyte = 1000 bytes (False)
+    :param gnu: say only order of magnitude (bool)  - 100 Kilo (True) or 100 Kilobytes (False)
+    :return: nice bytes (str)
+    """
+    if speech and gnu:
+        default_units = ['Bytes', 'Kilo', 'Mega', 'Giga', 'Tera', 'Peta',
+                         'Exa', 'Zetta', 'Yotta']
+    elif speech and binary:
+        default_units = ['Bytes', 'Kibibytes', 'Mebibytes', 'Gibibytes',
+                         'Tebibytes', 'Pebibytes', 'Exbibytes', 'Zebibytes',
+                         'Yobibytes']
+    elif speech:
+        default_units = ['Bytes', 'Kilobytes', 'Megabytes', 'Gigabytes',
+                         'Terabytes', 'Petabytes', 'Exabytes', 'Zettabytes',
+                         'Yottabytes']
+    elif gnu:
+        default_units = ['B', 'K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y']
+    elif binary:
+        default_units = ['B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB',
+                         'YiB']
+    else:
+        default_units = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']
+
+    units = default_units
+
+    if binary:
+        n = 1024
+    else:
+        n = 1000
+
+    for unit in units[:-1]:
+        if abs(number) < n:
+            if number == 1 and speech and not gnu:
+                # strip final "s"
+                unit = unit[:-1]
+            return "%3.1f %s" % (number, unit)
+        number /= n
+    return "%.1f %s" % (number, units[-1])
