@@ -13,13 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
+import re
 from difflib import SequenceMatcher
 from warnings import warn
 from lingua_nostra.time import now_local
 from lingua_nostra.internal import populate_localized_function_dict, \
     get_active_langs, get_full_lang_code, get_primary_lang_code, \
-    get_default_lang, localized_function, _raise_unsupported_language
+    get_default_lang, localized_function, FunctionNotLocalizedError
+from quantulum3 import parser as quantity_parser
+from lingua_nostra.lang.parse_common import ROMAN_NUMERALS
+from quebra_frases import span_indexed_empty_space_tokenize
+
 
 _REGISTERED_FUNCTIONS = ("extract_numbers",
                          "extract_number",
@@ -33,6 +37,94 @@ _REGISTERED_FUNCTIONS = ("extract_numbers",
 populate_localized_function_dict("parse", langs=get_active_langs())
 
 
+@localized_function(run_own_code_on=[FunctionNotLocalizedError])
+def normalize_decimals(text, decimal, lang=""):
+    """
+        Replace 'decimal' with decimal periods so Python can floatify them
+    """
+    regex = r"\b\d+" + decimal + r"{1}\d+\b"
+    sanitize_decimals = re.compile(regex)
+    for _, match in enumerate(re.finditer(sanitize_decimals, text)):
+        text = text.replace(match.group(
+            0), match.group(0).replace(decimal, '.'))
+    return text
+
+
+def roman_to_int(word):
+    if not is_roman_numeral(word):
+        return None
+    number = 0
+    for i in range(len(word)):
+        if i > 0 and ROMAN_NUMERALS[word[i]] > ROMAN_NUMERALS[word[i - 1]]:
+            number += ROMAN_NUMERALS[word[i]] - 2 * ROMAN_NUMERALS[word[i - 1]]
+        else:
+            number += ROMAN_NUMERALS[word[i]]
+    return number
+
+
+def is_roman_numeral(word):
+    return all(char in ROMAN_NUMERALS for char in word)
+
+
+def extract_roman_numeral_spans(utterance):
+    """
+    This function tags roman numerals in an utterance.
+
+    Args:
+        utterance (str): the string to normalize
+    Returns:
+        (list): list of tuples with detected number and span of the
+                number in parent utterance [(number, (start_idx, end_idx))]
+
+    """
+    spans = span_indexed_empty_space_tokenize(utterance)
+    return [(roman_to_int(word), (start, end)) for start, end, word in spans
+            if is_roman_numeral(word)]
+
+
+@localized_function(run_own_code_on=[FunctionNotLocalizedError])
+def normalize_roman_numerals(utterance, ordinals=False, lang=""):
+    # localization might be needed for ordinals flag
+    norm_utt = utterance
+    for num, (start, end) in reversed(extract_roman_numeral_spans(utterance)):
+        if ordinals:
+            if str(num)[-1] == "1":
+                num = f"{num}st"
+            elif str(num)[-1] == "2":
+                num = f"{num}nd"
+            elif str(num)[-1] == "3":
+                num = f"{num}rd"
+            else:
+                num = f"{num}th"
+        norm_utt = norm_utt[:start] + f"{num}" + norm_utt[end:]
+    return norm_utt
+
+
+@localized_function(run_own_code_on=[FunctionNotLocalizedError])
+def extract_quantities(utterance, raw=False, lang=''):
+    lang_code = get_primary_lang_code(lang)
+    bucket = []
+    try:
+        quants = quantity_parser.parse(utterance, lang=lang_code)
+    except NotImplementedError:
+        raise FunctionNotLocalizedError
+    remainder = utterance
+    for q in quants:
+        unit = {
+            "value": q.value,
+            "text": q.surface,
+            "span": q.span,
+            "unit": str(q.unit),
+            "uncertainty": q.uncertainty
+        }
+        remainder = remainder[:q.span[0]] + remainder[q.span[1]:]
+        bucket += [unit]
+    if raw:
+        return bucket
+    else:
+        return [(b["value"], b["text"]) for b in bucket]
+
+
 def fuzzy_match(x: str, against: str) -> float:
     """Perform a 'fuzzy' comparison between two strings.
 
@@ -74,7 +166,8 @@ def match_one(query, choices):
 
 
 @localized_function()
-def extract_numbers(text, short_scale=True, ordinals=False, lang=''):
+def extract_numbers(text, short_scale=True, ordinals=False, lang='',
+                    decimal='.'):
     """
         Takes in a string and extracts a list of numbers.
 
@@ -87,13 +180,18 @@ def extract_numbers(text, short_scale=True, ordinals=False, lang=''):
         ordinals (bool): consider ordinal numbers, e.g. third=3 instead of 1/3
         lang (str, optional): an optional BCP-47 language code, if omitted
                               the default language will be used.
+        decimal (str): character to use as decimal point. defaults to '.'
     Returns:
         list: list of extracted numbers as floats, or empty list if none found
+    Note:
+        will always extract numbers formatted with a decimal dot/full stop,
+        such as '3.5', even if 'decimal' is specified.
     """
 
 
 @localized_function()
-def extract_number(text, short_scale=True, ordinals=False, lang=''):
+def extract_number(text, short_scale=True, ordinals=False, lang='',
+                   decimal='.'):
     """Takes in a string and extracts a number.
 
     Args:
@@ -105,9 +203,13 @@ def extract_number(text, short_scale=True, ordinals=False, lang=''):
         ordinals (bool): consider ordinal numbers, e.g. third=3 instead of 1/3
         lang (str, optional): an optional BCP-47 language code, if omitted
                               the default language will be used.
+        decimal (str): character to use as decimal point. defaults to '.'
     Returns:
         (int, float or False): The number extracted or False if the input
                                text contains no numbers
+    Note:
+        will always extract numbers formatted with a decimal dot/full stop,
+        such as '3.5', even if 'decimal' is specified.
     """
 
 
