@@ -20,6 +20,7 @@ from lingua_nostra import load_language, unload_language, set_default_lang
 from lingua_nostra.format import nice_number
 from lingua_nostra.format import nice_time
 from lingua_nostra.format import pronounce_number
+from lingua_nostra.time import default_timezone
 
 
 def setUpModule():
@@ -184,7 +185,7 @@ class TestPronounceNumber_fr(unittest.TestCase):
 class TestNiceDateFormat_fr(unittest.TestCase):
     def test_convert_times_fr(self):
         dt = datetime.datetime(2017, 1, 31,
-                               13, 22, 3)
+                               13, 22, 3, tzinfo=default_timezone())
 
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "une heure vingt-deux")
@@ -209,7 +210,7 @@ class TestNiceDateFormat_fr(unittest.TestCase):
                          "treize heures vingt-deux")
 
         dt = datetime.datetime(2017, 1, 31,
-                               13, 0, 3)
+                               13, 0, 3, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "une heure")
         self.assertEqual(nice_time(dt, lang="fr-fr", use_ampm=True),
@@ -233,7 +234,7 @@ class TestNiceDateFormat_fr(unittest.TestCase):
                          "treize heures")
 
         dt = datetime.datetime(2017, 1, 31,
-                               13, 2, 3)
+                               13, 2, 3, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "une heure deux")
         self.assertEqual(nice_time(dt, lang="fr-fr", use_ampm=True),
@@ -257,7 +258,7 @@ class TestNiceDateFormat_fr(unittest.TestCase):
                          "treize heures deux")
 
         dt = datetime.datetime(2017, 1, 31,
-                               0, 2, 3)
+                               0, 2, 3, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "minuit deux")
         self.assertEqual(nice_time(dt, lang="fr-fr", use_ampm=True),
@@ -281,7 +282,7 @@ class TestNiceDateFormat_fr(unittest.TestCase):
                          "minuit deux")
 
         dt = datetime.datetime(2017, 1, 31,
-                               12, 15, 9)
+                               12, 15, 9, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "midi et quart")
         self.assertEqual(nice_time(dt, lang="fr-fr", use_ampm=True),
@@ -305,7 +306,7 @@ class TestNiceDateFormat_fr(unittest.TestCase):
                          "midi quinze")
 
         dt = datetime.datetime(2017, 1, 31,
-                               19, 40, 49)
+                               19, 40, 49, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "huit heures moins vingt")
         self.assertEqual(nice_time(dt, lang="fr-fr", use_ampm=True),
@@ -329,32 +330,32 @@ class TestNiceDateFormat_fr(unittest.TestCase):
                          "dix-neuf heures quarante")
 
         dt = datetime.datetime(2017, 1, 31,
-                               1, 15, 00)
+                               1, 15, 00, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr", use_24hour=True),
                          "une heure quinze")
 
         dt = datetime.datetime(2017, 1, 31,
-                               1, 35, 00)
+                               1, 35, 00, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "deux heures moins vingt-cinq")
 
         dt = datetime.datetime(2017, 1, 31,
-                               1, 45, 00)
+                               1, 45, 00, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "deux heures moins le quart")
 
         dt = datetime.datetime(2017, 1, 31,
-                               4, 50, 00)
+                               4, 50, 00, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "cinq heures moins dix")
 
         dt = datetime.datetime(2017, 1, 31,
-                               5, 55, 00)
+                               5, 55, 00, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr"),
                          "six heures moins cinq")
 
         dt = datetime.datetime(2017, 1, 31,
-                               5, 30, 00)
+                               5, 30, 00, tzinfo=default_timezone())
         self.assertEqual(nice_time(dt, lang="fr-fr", use_ampm=True),
                          "cinq heures et demi du matin")
 
